package Chart::Clicker::Decoration::Base;
use strict;
use warnings;

use base 'Chart::Clicker::Drawing::Component';

1;
__END__

=head1 NAME

Chart::Clicker::Decoration::Base

=head1 DESCRIPTION

Chart::Clicker::Decoration::Base.

=head1 SYNOPSIS

=head1 METHODS

=head2 Constructor

=over 4

=item new

Creates a new Chart::Clicker::Decoration::Base.

=back

=head2 Class Methods

=over 4

=back

=head1 AUTHOR

Cory 'G' Watson <gphat@cpan.org>

=head1 SEE ALSO

perl(1)

=head1 LICENSE

You can redistribute and/or modify this code under the same terms as Perl
itself.
